Learn R Programming

RcppMeCab (version 0.0.1.7)

list_dic: List installed MeCab dictionaries

Description

Shows all available MeCab dictionaries, including the bundled dictionary and any downloaded via download_dic.

Usage

list_dic()

Arguments

Value

A data frame with columns lang, name, path, and active.

Examples

Run this code
if (FALSE) {
list_dic()
}

Run the code above in your browser using DataLab