powered by
Shows all available MeCab dictionaries, including the bundled dictionary and any downloaded via download_dic.
download_dic
list_dic()
A data frame with columns lang, name, path, and active.
lang
name
path
active
if (FALSE) { list_dic() }
Run the code above in your browser using DataLab